==> dokuwiki-2018.04.22ap2.tgz: dokuwiki/lib/plugins/extension/lang/de-informal/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Felix <j.felix@mueller-donath.de>
 */
$lang['menu']                  = 'Erweiterungen verwalten';
$lang['tab_plugins']           = 'Installierte Plugins';
$lang['tab_templates']         = 'Installierte Templates';
$lang['tab_search']            = 'Suchen und installieren';
$lang['tab_install']           = 'Manuelle Installation';
$lang['notimplemented']        = 'Dieses Feature wurde leider noch nicht eingebaut';
$lang['notinstalled']          = 'Diese Erweiterung ist nicht installiert';
$lang['alreadyenabled']        = 'Diese Erweiterung wurde bereits aktiviert';
$lang['alreadydisabled']       = 'Diese Erweiterung wurde bereits deaktiviert';
$lang['pluginlistsaveerror']   = 'Fehler beim Speichern der Plugin-Liste';
$lang['unknownauthor']         = 'Unbekannter Autor';
$lang['unknownversion']        = 'Unbekannte Version';
$lang['btn_info']              = 'Zeige mehr Infos';
$lang['btn_update']            = 'Update';
$lang['btn_uninstall']         = 'Deinstallation';
$lang['btn_enable']            = 'Aktivieren';
$lang['btn_disable']           = 'Deaktivieren';
$lang['btn_install']           = 'Installation';
$lang['btn_reinstall']         = 'Neuinstallation';
$lang['js']['reallydel']       = 'Möchtest du diese Erweiterung wirklich deinstallieren';
$lang['js']['display_viewoptions'] = 'Einstellungen anzeigen:';
$lang['js']['display_enabled'] = 'aktiviert';
$lang['js']['display_disabled'] = 'deaktiviert';
$lang['js']['display_updatable'] = 'Update verfügbar';
$lang['search_for']            = 'Suche Erweiterung:';
$lang['search']                = 'Suche';
$lang['extensionby']           = '<strong>%s</strong> von %s';
$lang['screenshot']            = 'Screenshot von %s';
$lang['popularity']            = 'Popularität: %s%%';
$lang['homepage_link']         = 'Doku';
$lang['bugs_features']         = 'Bugs';
$lang['tags']                  = 'Schlagworte:';
$lang['author_hint']           = 'Suche Erweiterungen dieses Autors';
$lang['installed']             = 'Installiert:';
$lang['downloadurl']           = 'URL zum Herunterladen:';
$lang['repository']            = 'Quelle:';
$lang['unknown']               = '<em>unbekannt</em>';
$lang['installed_version']     = 'Installierte Version:';
$lang['install_date']          = 'Dein letztes Update:';
$lang['available_version']     = 'Verfügbare Version:';
$lang['compatible']            = 'Kompatibel mit:';
$lang['depends']               = 'Abhängig von:';
$lang['similar']               = 'Ähnlich wie:';
$lang['conflicts']             = 'Nicht kompatibel mit:';
$lang['donate']                = 'Nützlich?';
$lang['donate_action']         = 'Spendiere dem Autor einen Kaffee!';
$lang['repo_retry']            = 'Wiederholen';
$lang['provides']              = 'Enthält:';
$lang['status']                = 'Status';
$lang['status_installed']      = 'installiert';
$lang['status_not_installed']  = 'nicht installiert';
$lang['status_protected']      = 'geschützt';
$lang['status_enabled']        = 'aktiviert';
$lang['status_disabled']       = 'deaktiviert';
$lang['status_unmodifiable']   = 'unveränderlich';
$lang['status_plugin']         = 'Plugin';
$lang['status_template']       = 'Template';
$lang['status_bundled']        = 'gebündelt';
$lang['msg_enabled']           = 'Plugin %s ist aktiviert';
$lang['msg_disabled']          = 'Erweiterung %s ist deaktiviert';
$lang['msg_delete_success']    = 'Erweiterung %s wurde entfernt';
$lang['msg_delete_failed']     = 'Deinstallation der Erweiterung %s fehlgeschlagen';
$lang['msg_template_install_success'] = 'Das Template %s wurde erfolgreich installiert';
$lang['msg_template_update_success'] = 'Das Update des Templates %s war erfolgreich ';
$lang['msg_plugin_install_success'] = 'Das Plugin %s wurde erfolgreich installiert';
$lang['msg_plugin_update_success'] = 'Das Update des Plugins %s war erfolgreich';
$lang['msg_upload_failed']     = 'Fehler beim Hochladen der Datei';
$lang['missing_dependency']    = '<strong>Fehlende oder deaktivierte Abhängigkeit:<strong>%s';
$lang['security_issue']        = '<strong>Sicherheitsproblem:</strong> %s';
$lang['security_warning']      = '<strong>Sicherheitswarnung:</strong> %s';
$lang['update_available']      = '<strong>Update:</strong> Version %s steht zum Download bereit.';
$lang['wrong_folder']          = '<strong>Plugin wurde nicht korrekt installiert:</strong> Benenne das Plugin-Verzeichnis "%s" in "%s" um.';
$lang['url_change']            = '<strong>URL geändert:</strong> Die Download URL wurde seit dem letzten Download geändert. Internetadresse vor Aktualisierung der Erweiterung auf Gültigkeit prüfen.<br />Neu: %s<br />Alt: %s';
$lang['error_badurl']          = 'URLs sollten mit http oder https beginnen';
$lang['error_dircreate']       = 'Temporärer Ordner konnte nicht erstellt werden um Download zu abzuspeichern';
$lang['error_download']        = 'Download der Datei: %s nicht möglich.';
$lang['error_decompress']      = 'Die heruntergeladene Datei konnte nicht entpackt werden. Dies kann die Folge eines fehlerhaften Downloads sein. In diesem Fall solltest du versuchen den Vorgang zu wiederholen. Es kann auch die Folge eines unbekannten Kompressionsformates sein, in diesem ​​Fall musst du die Datei selber herunterladen und manuell installieren.';
$lang['error_findfolder']      = 'Das Erweiterungs-Verzeichnis konnte nicht identifiziert werden, lade die Datei herunter und installiere sie manuell.';
$lang['error_copy']            = 'Beim Versuch Dateien in den Ordner <em>%s</em>: zu installieren trat ein Kopierfehler auf. Die Dateizugriffsberechtigungen könnten falsch sein. Dies kann an einem unvollständig installierten Plugin liegen und beeinträchtigt somit die Stabilität deiner Wiki-Installation.';
$lang['noperms']               = 'Das Erweiterungs-Verzeichnis ist schreibgeschützt';
$lang['notplperms']            = 'Das Template-Verzeichnis ist schreibgeschützt';
$lang['nopluginperms']         = 'Das Plugin-Verzeichnis ist schreibgeschützt';
$lang['git']                   = 'Diese Erweiterung wurde über git installiert und sollte daher nicht hier aktualisiert werden.';
$lang['auth']                  = 'Dieses Auth Plugin ist in der Konfiguration nicht aktiviert, Du solltest es deaktivieren.';
$lang['install_url']           = 'Von URL installieren:';
$lang['install_upload']        = 'Erweiterung hochladen:';
$lang['repo_error']            = 'Es konnte keine Verbindung zum Plugin-Verzeichnis hergestellt werden. Stelle sicher dass der Server Verbindung mit www.dokuwiki.org aufnehmen darf und überprüfe deine Proxy-Einstellungen.';
$lang['nossl']                 = 'Deine PHP-Installation scheint SSL nicht zu unterstützen. Das Herunterladen vieler DokuWiki Erweiterungen wird scheitern.';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/extension/lang/de-informal/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author MaWi <drmaxxis@gmail.com>
 * @author Felix <j.felix@mueller-donath.de>
 */
$lang['menu']                  = 'Erweiterungen verwalten';
$lang['tab_plugins']           = 'Installierte Plugins';
$lang['tab_templates']         = 'Installierte Templates';
$lang['tab_search']            = 'Suchen und installieren';
$lang['tab_install']           = 'Manuelle Installation';
$lang['notimplemented']        = 'Dieses Feature wurde leider noch nicht eingebaut';
$lang['notinstalled']          = 'Diese Erweiterung ist nicht installiert';
$lang['alreadyenabled']        = 'Diese Erweiterung wurde bereits aktiviert';
$lang['alreadydisabled']       = 'Diese Erweiterung wurde bereits deaktiviert';
$lang['pluginlistsaveerror']   = 'Fehler beim Speichern der Plugin-Liste';
$lang['unknownauthor']         = 'Unbekannter Autor';
$lang['unknownversion']        = 'Unbekannte Version';
$lang['btn_info']              = 'Zeige mehr Infos';
$lang['btn_update']            = 'Update';
$lang['btn_uninstall']         = 'Deinstallation';
$lang['btn_enable']            = 'Aktivieren';
$lang['btn_disable']           = 'Deaktivieren';
$lang['btn_install']           = 'Installation';
$lang['btn_reinstall']         = 'Neuinstallation';
$lang['js']['reallydel']       = 'Möchtest du diese Erweiterung wirklich deinstallieren';
$lang['js']['display_viewoptions'] = 'Einstellungen anzeigen:';
$lang['js']['display_enabled'] = 'aktiviert';
$lang['js']['display_disabled'] = 'deaktiviert';
$lang['js']['display_updatable'] = 'Update verfügbar';
$lang['search_for']            = 'Suche Erweiterung:';
$lang['search']                = 'Suche';
$lang['extensionby']           = '<strong>%s</strong> von %s';
$lang['screenshot']            = 'Screenshot von %s';
$lang['popularity']            = 'Popularität: %s%%';
$lang['homepage_link']         = 'Doku';
$lang['bugs_features']         = 'Bugs';
$lang['tags']                  = 'Schlagworte:';
$lang['author_hint']           = 'Suche Erweiterungen dieses Autors';
$lang['installed']             = 'Installiert:';
$lang['downloadurl']           = 'URL zum Herunterladen:';
$lang['repository']            = 'Quelle:';
$lang['unknown']               = '<em>unbekannt</em>';
$lang['installed_version']     = 'Installierte Version:';
$lang['install_date']          = 'Dein letztes Update:';
$lang['available_version']     = 'Verfügbare Version:';
$lang['compatible']            = 'Kompatibel mit:';
$lang['depends']               = 'Abhängig von:';
$lang['similar']               = 'Ähnlich wie:';
$lang['conflicts']             = 'Nicht kompatibel mit:';
$lang['donate']                = 'Nützlich?';
$lang['donate_action']         = 'Spendiere dem Autor einen Kaffee!';
$lang['repo_retry']            = 'Wiederholen';
$lang['provides']              = 'Enthält:';
$lang['status']                = 'Status';
$lang['status_installed']      = 'installiert';
$lang['status_not_installed']  = 'nicht installiert';
$lang['status_protected']      = 'geschützt';
$lang['status_enabled']        = 'aktiviert';
$lang['status_disabled']       = 'deaktiviert';
$lang['status_unmodifiable']   = 'unveränderlich';
$lang['status_plugin']         = 'Plugin';
$lang['status_template']       = 'Template';
$lang['status_bundled']        = 'gebündelt';
$lang['msg_enabled']           = 'Plugin %s ist aktiviert';
$lang['msg_disabled']          = 'Erweiterung %s ist deaktiviert';
$lang['msg_delete_success']    = 'Erweiterung %s wurde entfernt';
$lang['msg_delete_failed']     = 'Deinstallation der Erweiterung %s fehlgeschlagen';
$lang['msg_template_install_success'] = 'Das Template %s wurde erfolgreich installiert';
$lang['msg_template_update_success'] = 'Das Update des Templates %s war erfolgreich ';
$lang['msg_plugin_install_success'] = 'Das Plugin %s wurde erfolgreich installiert';
$lang['msg_plugin_update_success'] = 'Das Update des Plugins %s war erfolgreich';
$lang['msg_upload_failed']     = 'Fehler beim Hochladen der Datei';
$lang['msg_nooverwrite']       = 'Die Erweiterung %s ist bereits vorhanden, sodass sie nicht überschrieben wird. Zum Überschreiben aktiviere die Option "Überschreiben".';
$lang['missing_dependency']    = '<strong>Fehlende oder deaktivierte Abhängigkeit:<strong>%s';
$lang['security_issue']        = '<strong>Sicherheitsproblem:</strong> %s';
$lang['security_warning']      = '<strong>Sicherheitswarnung:</strong> %s';
$lang['update_available']      = '<strong>Update:</strong> Version %s steht zum Download bereit.';
$lang['wrong_folder']          = '<strong>Plugin wurde nicht korrekt installiert:</strong> Benenne das Plugin-Verzeichnis "%s" in "%s" um.';
$lang['url_change']            = '<strong>URL geändert:</strong> Die Download-URL wurde seit dem letzten Download geändert. Internetadresse vor Aktualisierung der Erweiterung auf Gültigkeit prüfen.<br />Neu: %s<br />Alt: %s';
$lang['error_badurl']          = 'URLs sollten mit http oder https beginnen';
$lang['error_dircreate']       = 'Temporärer Ordner konnte nicht erstellt werden um Download zu abzuspeichern';
$lang['error_download']        = 'Download der Datei: %s nicht möglich.';
$lang['error_decompress']      = 'Die heruntergeladene Datei konnte nicht entpackt werden. Dies kann die Folge eines fehlerhaften Downloads sein. In diesem Fall solltest du versuchen den Vorgang zu wiederholen. Es kann auch die Folge eines unbekannten Kompressionsformates sein, in diesem Fall musst du die Datei selber herunterladen und manuell installieren.';
$lang['error_findfolder']      = 'Das Erweiterungs-Verzeichnis konnte nicht identifiziert werden, lade die Datei herunter und installiere sie manuell.';
$lang['error_copy']            = 'Beim Versuch Dateien in den Ordner <em>%s</em>: zu installieren trat ein Kopierfehler auf. Die Dateizugriffsberechtigungen könnten falsch sein. Dies kann an einem unvollständig installierten Plugin liegen und beeinträchtigt somit die Stabilität deiner Wiki-Installation.';
$lang['noperms']               = 'Das Erweiterungs-Verzeichnis ist schreibgeschützt';
$lang['notplperms']            = 'Das Template-Verzeichnis ist schreibgeschützt';
$lang['nopluginperms']         = 'Das Plugin-Verzeichnis ist schreibgeschützt';
$lang['git']                   = 'Diese Erweiterung wurde über git installiert und sollte daher nicht hier aktualisiert werden.';
$lang['auth']                  = 'Dieses Auth-Plugin ist in der Konfiguration nicht aktiviert, Du solltest es deaktivieren.';
$lang['install_url']           = 'Von URL installieren:';
$lang['install_upload']        = 'Erweiterung hochladen:';
$lang['repo_error']            = 'Es konnte keine Verbindung zum Plugin-Verzeichnis hergestellt werden. Stelle sicher, dass der Server Verbindung mit www.dokuwiki.org aufnehmen darf und überprüfe deine Proxy-Einstellungen.';
$lang['nossl']                 = 'Deine PHP-Installation scheint SSL nicht zu unterstützen. Das Herunterladen vieler DokuWiki-Erweiterungen wird scheitern.';
